@@ -35,8 +35,7 @@ class Event:
 
     def __init__(self, event_uri, platformKey: str, secret=None, httpHeaders={}):
         event_uri= getValue(event_uri)
-        self._event_uri = event_uri + \
-            ('/' if event_uri.find('/', len(event_uri)-1) <= -1 else '')
+        self._event_uri = event_uri.rstrip('/')+"/"+"api/"
         self._platformKey = platformKey
         self._httpHeaders = httpHeaders
         self._httpHeaders['api-token'] = secret if secret else ''
@@ -153,7 +152,7 @@ class Manager:
             -   platformKey:<str>, event platform key index.
             -   RPCInstance:<TDhelper.network.http.RPC>, RPC instace. then trigger handle type is rpc must use it.
         '''
-        self._event_service_uri = getValue(service_uri)  # 事件服务地址
+        self._event_service_uri = getValue(service_uri).rstrip("/")+"/api/"  # 事件服务地址
         self._event_httpHeaders = {}
         self._event_httpHeaders['api-token'] = event_secret if event_secret else ''
         self._event_cache = {}  # 事件缓存
