@@ -14,7 +14,7 @@
 from TDhelper.robot.struct.base import joint
 # code start
 class HIP:
-    def __init__(self, joints:[]= None):
+    def __init__(self, joints:list= None):
         '''
             胯初始化
             - params:
